@@ -3,14 +3,15 @@
 
 """Šis ir testa skripts"""
 
-def paradit_listi(liste, limenis = 0):
+def paradit_listi(liste, indent = False, limenis = 0):
 
 	"""Funkcijas kaut ko dara, bet es aizmirsu ko"""
 
 	for maz_liste in liste:
 		if isinstance(maz_liste, list):
-			paradit_listi(maz_liste, limenis + 1)
+			paradit_listi(maz_liste, indent, limenis + 1)
 		else:
-			for tab in range(limenis):
-				print("\t", end="")
+			if indent:
+				for tab in range(limenis):
+					print("\t", end="")
 			print(maz_liste)
